==> bplan-base-globals-1.1.0-0b4347.zip: lang/uk/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'uk',
    'language' => 'Українська',
    'locale' => 'uk_UA',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value ₴',
    'currency.format.negative' => '-:value ₴',
    'currency.iso4217.alpha'   => 'UAH',
    'currency.iso4217.numeric' => 980,
    'currency.name'            => 'Гривня',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Копійка',
    'currency.subunit.symbol'  => 'коп.',
    'currency.symbol'          => '₴',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Активувати',
    'action.add'           => 'Додати',
    'action.cancel'        => 'Скасувати',
    'action.cancel-upload' => 'Скасувати завантаження',
    'action.change'        => 'Змінити',
    'action.close'         => 'Закрити',
    'action.confirm'       => 'Підтвердити',
    'action.deactivate'    => 'Деактивувати',
    'action.delete'        => 'Видалити',
    'action.edit'          => 'Редагувати',
    'action.import'        => 'Імпортувати',
    'action.print'         => 'Друкувати',
    'action.save'          => 'Зберегти',
    'action.search'        => 'Шукати',
    'action.sync'          => 'Синхронізувати',
    'action.upload'        => 'Завантажити файл',
    'action.verify'        => 'Перевірити',
    'action.view'          => 'Переглянути',

    'languages' => [
        'bg' => 'Болгарська',
        'de' => 'Німецька',
        'en' => 'Англійська',
        'es' => 'Іспанська',
        'fr' => 'Французька',
        'hu' => 'Угорська',
        'it' => 'Італійська',
        'lt' => 'Литовська',
        'pl' => 'Польська',
        'ro' => 'Румунська',
        'ru' => 'Російська',
        'tr' => 'Турецька',
        'uk' => 'Українська',
    ],

    'option.yes' => 'Так',
    'option.no'  => 'Ні',

    'required-hint'   => 'Позначені поля (<span class="required-marker">:marker</span>) є обов\'язковими',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Будь ласка, виберіть -- ',

    'status.active'   => 'Активний',
    'status.expired'  => 'Закінчився',
    'status.inactive' => 'Неактивний',
    'status.invalid'  => 'Невірний',
    'status.loading'  => 'Завантажується...',
    'status.not-set'  => 'Не встановлено',
    'status.valid'    => 'Дійсний',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/uk/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'uk',
    'language' => 'Українська',
    'locale' => 'uk_UA',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value ₴',
    'currency.format.negative' => '-:value ₴',
    'currency.iso4217.alpha'   => 'UAH',
    'currency.iso4217.numeric' => 980,
    'currency.name'            => 'Гривня',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Копійка',
    'currency.subunit.symbol'  => 'коп.',
    'currency.symbol'          => '₴',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Активувати',
    'action.add'           => 'Додати',
    'action.cancel'        => 'Скасувати',
    'action.cancel-upload' => 'Скасувати завантаження',
    'action.change'        => 'Змінити',
    'action.close'         => 'Закрити',
    'action.confirm'       => 'Підтвердити',
    'action.deactivate'    => 'Деактивувати',
    'action.delete'        => 'Видалити',
    'action.edit'          => 'Редагувати',
    'action.import'        => 'Імпортувати',
    'action.print'         => 'Друкувати',
    'action.save'          => 'Зберегти',
    'action.search'        => 'Шукати',
    'action.sync'          => 'Синхронізувати',
    'action.upload'        => 'Завантажити файл',
    'action.verify'        => 'Перевірити',
    'action.view'          => 'Переглянути',

    'languages' => [
        'bg' => 'Болгарська',
        'de' => 'Німецька',
        'en' => 'Англійська',
        'es' => 'Іспанська',
        'fr' => 'Французька',
        'hu' => 'Угорська',
        'it' => 'Італійська',
        'lt' => 'Литовська',
        'pl' => 'Польська',
        'ro' => 'Румунська',
        'ru' => 'Російська',
        'tr' => 'Турецька',
        'uk' => 'Українська',
    ],

    'option.yes' => 'Так',
    'option.no'  => 'Ні',

    'required-hint'   => 'Позначені поля (<span class="required-marker">:marker</span>) є обов\'язковими',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Опції не доступні',
    'select-option.please-select'        => ' -- Будь ласка, виберіть -- ',

    'status.active'   => 'Активний',
    'status.expired'  => 'Закінчився',
    'status.inactive' => 'Неактивний',
    'status.invalid'  => 'Невірний',
    'status.loading'  => 'Завантажується...',
    'status.not-set'  => 'Не встановлено',
    'status.valid'    => 'Дійсний',

];
